@@ -11,7 +11,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $SPACE => q{ };
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Resets internal variables.
 sub reset {
@@ -184,17 +184,19 @@ CSS::Struct::Output::Indent - Indent printing 'CSS::Struct' structure to CSS cod
  use CSS::Struct::Output::Indent;
 
  my $css = CSS::Struct::Output::Indent->new(%parameters);
+ my $ret_or_undef = $css->flush($reset_flag);
  $css->put(@data);
- $css->flush;
  $css->reset;
 
 =head1 METHODS
 
-=over 8
+=head2 C<new>
 
-=item C<new(%parameters)>
+ my $css = CSS::Struct::Output::Indent->new(%parameters);
 
- Constructor.
+Constructor.
+
+Returns instance of object.
 
 =over 8
 
@@ -234,22 +236,32 @@ CSS::Struct::Output::Indent - Indent printing 'CSS::Struct' structure to CSS cod
 
 =back
 
-=item C<flush($reset_flag)>
+=head2 C<flush>
 
- Flush CSS structure in object.
- If defined 'output_handler' flush to its.
- Or return code.
- If enabled $reset_flag, then resets internal variables via reset method.
+ my $ret_or_undef = $css->flush($reset_flag);
 
-=item C<put(@data)>
+Flush CSS structure in object.
+If defined 'output_handler' flush to its.
+Or return CSS.
+If enabled $reset_flag, then resets internal variables via reset method.
 
- Put CSS structure in format specified in L<CSS::Struct>.
+Returns output string or undef.
 
-=item C<reset()>
+=head2 C<put(@data)>
 
- Resets internal variables.
+ $css->put(@data);
 
-=back
+Put CSS structure in format specified in L<CSS::Struct>.
+
+Returns undef.
+
+=head2 C<reset>
+
+ $css->reset;
+
+Resets internal variables.
+
+Returns undef.
 
 =head1 ERRORS
 
@@ -265,6 +277,32 @@ CSS::Struct::Output::Indent - Indent printing 'CSS::Struct' structure to CSS cod
          Output handler is bad file handler.
          Unknown parameter '%s'.
 
+=head1 EXAMPLE
+
+ use strict;
+ use warnings;
+
+ use CSS::Struct::Output::Indent;
+
+ my $css = CSS::Struct::Output::Indent->new(
+         'output_handler' => \*STDOUT,
+ );
+
+ $css->put(['s', 'selector#id']);
+ $css->put(['s', 'div div']);
+ $css->put(['s', '.class']);
+ $css->put(['d', 'weight', '100px']);
+ $css->put(['d', 'font-size', '10em']);
+ $css->put(['e']);
+ $css->flush;
+ print "\n";
+
+ # Output:
+ # selector#id, div div, .class {
+ #         weight: 100px;
+ #         font-size: 10em;
+ # }
+
 =head1 DEPENDENCIES
 
 L<CSS::Struct::Output>,
@@ -301,12 +339,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2011-2020 Michal Josef Špaček
+© 2011-2021 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
